@@ -2,9 +2,9 @@ context("Scores")
 
 source("objects_for_tests.R")
 
-test_that("scoreGQ", {
-  expect_is(scoreGQ(au.lm, "income"), "scoreAudit")
-  expect_is(scoreGQ(au.rf), "scoreAudit")
+test_that("scorePeak", {
+  expect_is(scorePeak(au.lm, "income"), "scoreAudit")
+  expect_is(scorePeak(au.rf), "scoreAudit")
 })
 
 test_that("scoreDW", {
@@ -29,12 +29,14 @@ test_that("scoreHalfNormal", {
 })
 
 test_that("score", {
-  expect_is(score(au.lm, "GQ", variable="income"), "scoreAudit")
+  expect_is(score(au.lm, "Peak", variable="income"), "scoreAudit")
   expect_is(score(au.lm, "DW", variable="income"), "scoreAudit")
   expect_is(score(au.lm, "Runs", variable="income"), "scoreAudit")
   expect_is(score(au.lm, "HalfNormal"), "scoreAudit")
+  expect_is(score(au.lm, "RMSE"), "scoreAudit")
+  expect_is(score(au.class.glm, "ROC"), "scoreAudit")
   expect_is(score(au.lm, "CooksDistance"), "numeric")
-  expect_error(score(model.lm))
+  expect_error(score(model.lm, type = "Runs"))
   expect_error(score(au.lm,"wrongScore"))
 })
 
